Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(477)

Unified Diff: components/safe_browsing/csd.proto

Issue 2777853005: Generalize the usage of referrer chain (Closed)
Patch Set: nit Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/safe_browsing/csd.proto
diff --git a/components/safe_browsing/csd.proto b/components/safe_browsing/csd.proto
index eb2d75e932b54bd998d0f4449013e94fdd3b3955..af9b86333d078252161d28d32d13e272d0301163 100644
--- a/components/safe_browsing/csd.proto
+++ b/components/safe_browsing/csd.proto
@@ -506,7 +506,7 @@ message ClientDownloadRequest {
message ReferrerChainEntry {
enum URLType {
- DOWNLOAD_URL = 1;
+ EVENT_URL = 1;
lpz 2017/03/29 13:46:27 "Event" is a little vague, perhaps some comments o
Jialiu Lin 2017/03/29 20:40:00 Done.
LANDING_PAGE = 2;
LANDING_REFERRER = 3;
CLIENT_REDIRECT = 4;
@@ -526,7 +526,7 @@ message ReferrerChainEntry {
// Only set if it is different from |url|.
optional string main_frame_url = 9;
// Type of URLs, such as download url, download referrer, etc.
optional URLType type = 2 [default = CLIENT_REDIRECT];
// IP addresses corresponding to this host.
@@ -526,7 +526,7 @@ message ReferrerChainEntry {
// Only set if it is different from |url|.
optional string main_frame_url = 9;
- // Type of URLs, such as download url, download referrer, etc.
+ // Type of URLs, such as event url, landing page, etc.
optional URLType type = 2 [default = CLIENT_REDIRECT];
// IP addresses corresponding to this host.

Powered by Google App Engine
This is Rietveld 408576698